@@ -1,7 +1,9 @@
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  labeltable(var,
 #      ...,
 #      out=NA,
+#      count=FALSE,
+#      percent=FALSE,
 #      file=NA,
 #      desc=NA,
 #      note=NA,
@@ -20,7 +22,12 @@ labeltable(efc$e15relat)
 data(mtcars)
 labeltable(mtcars$cyl,mtcars$carb,mtcars$am)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
+library(vtable)
+data(LifeCycleSavings)
+labeltable(efc$e15relat, count = TRUE, percent = TRUE)
+
+## ----eval=FALSE---------------------------------------------------------------
 #  library(vtable)
 #  
 #  data(LifeCycleSavings)
